Business Combinations - Purchase Price Allocation — Calcbench API Client documentation

# Business Combinations - Purchase Price Allocation

Purchase price allocation and intangible useful lives for acquisitions and mergers.

class calcbench.business_combinations.BusinessCombination(**kwargs)
  acquisition_date: datetime.datetime
  date_originally_reported: datetime.datetime
  date_reported: datetime.datetime
  enterprise_value: float
  intangible_categories: Dict[str, calcbench.business_combinations.IntangibleCategory]
  parent_company: str
  parent_company_SIC_code: str
  parent_company_state: str
  parent_company_ticker: str
  purchase_price: calcbench.standardized_numeric.StandardizedPoint
  standardized_PPA_points: Dict[str, calcbench.standardized_numeric.StandardizedPoint]
  target: str
  trace_link: str

class calcbench.business_combinations.IntangibleCategory(**kwargs)
  category: str
  useful_life_lower_range: float
  useful_life_upper_range: float
  value: float

calcbench.business_combinations.business_combinations(company_identifiers=[], accession_id=None)

  Purchase price allocation for mergers and acquisitions.

  Columns are standardized metrics.

  Parameters

    - company_identifiers (`Sequence`[`Union`[`str`, `int`]]) – Companies for which to retrieve data

    - accession_id (`Optional`[`int`]) – Calcbench accession(filing) id for which to retrieve data. Get data for one filing.

  Return type

    `DataFrame`

calcbench.business_combinations.business_combinations_raw(company_identifiers=[], accession_id=None)

  Purchase price allocation for mergers and acquisitions.

  Parameters

    - company_identifiers (`Sequence`[`Union`[`str`, `int`]]) – Companies for which to retrieve data

    - accession_id (`Optional`[`int`]) – Calcbench accession(filing) id for which to retrieve data. Get data for one filing.

  Return type

    `Generator`[`BusinessCombination`, `None`, `None`]

calcbench.business_combinations.legacy_report(company_identifiers=[], accession_id=None)

  This is used by a Calcbench client that shall not be named.